@@ -3,9 +3,10 @@ OC.L10N.register(
     {
     "Today" : "Hiziv",
     "All" : "Pep tra",
+    "Current" : "A red",
     "Completed" : "Achuet",
     "Cancel" : "Arrest",
-    "Save" : "Entilañ",
+    "Save" : "Enrollañ",
     "can edit" : "posuple eo embann",
     "Edit" : "Cheñch",
     "Download" : "Pellgargañ",
